#
# spec file for package liborcus
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%bcond_without tests
%define libname liborcus-0_18-0
Name:           liborcus
Version:        0.18.1
Release:        3.4
Summary:        Spreadsheet file processing library
License:        MPL-2.0
URL:            https://gitlab.com/orcus/orcus/
Source:         http://kohei.us/files/orcus/src/%{name}-%{version}.tar.xz
Patch0:         0001-Possibility-to-build-against-a-host-of-filesystem-im.patch
Patch1:         0002-Allow-using-older-boost-filesystem.patch
Patch2:         0003-Allow-running-tests-with-python-3.4.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  coreutils
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-xml
BuildRequires:  pkgconfig(libixion-0.18)
BuildRequires:  pkgconfig(mdds-2.1) >= 2.0.99
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} >= 1500
BuildRequires:  gcc >= 7
BuildRequires:  gcc-c++ >= 7
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
%else
BuildRequires:  boost-devel
BuildRequires:  gcc7
BuildRequires:  gcc7-c++
%endif

%package -n %{libname}
Summary:        Spreadsheet file processing library

%description -n %{libname}
Standalone file import filter library for spreadsheet documents. Currently
under development are ODS, XLSX and CSV import filters.

%description
Standalone file import filter library for spreadsheet documents. Currently
under development are ODS, XLSX and CSV import filters.

%package devel
Summary:        Spreadsheet file processing library
Requires:       %{libname} = %{version}
Requires:       pkgconfig(zlib)

%description devel
Standalone file import filter library for spreadsheet documents. Currently
under development are ODS, XLSX and CSV import filters.

%package tools
Summary:        Spreadsheet file processing library
Requires:       %{libname} = %{version}

%description tools
Tools to work with various xml streams.

%package -n python3-%{name}
Summary:        Python bindings for liborcus
Provides:       %{name}-python3 = %{version}

%description -n python3-%{name}
Python 3 bindings for %{name}.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
%global optflags %{optflags} -fexcess-precision=fast
NOCONFIGURE=indeed ./autogen.sh
%if 0%{?suse_version} < 1500
export CC=gcc-7
export CXX=g++-7
%endif
%configure \
	--disable-silent-rules \
	--disable-static \
	--disable-debug \
	--disable-werror \
	--docdir=%{_docdir}/%{name}
%make_build

%if %{with tests}
%check
%make_build check
%endif

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files tools
%{_bindir}/*

%files -n python3-%{name}
%dir %{python3_sitelib}/orcus/
%{python3_sitelib}/orcus/*
%{python3_sitearch}/_orcus.so
%{python3_sitearch}/_orcus_json.so

%changelog
* Fri Aug 11 2023 Fridrich Strba <fstrba@suse.com>
- Removed patches:
  * liborcus-filesystem.patch
  * liborcus-tests.patch
    + reworked in order to send them upstream
- Added patches:
  * 0001-Possibility-to-build-against-a-host-of-filesystem-im.patch
  * 0003-Allow-running-tests-with-python-3.4.patch
  * 0002-Allow-using-older-boost-filesystem.patch
    + split into chunks per topic so that upsteam can decide what
    to do
* Thu Aug 10 2023 Fridrich Strba <fstrba@suse.com>
- Clean up the spec file and require gcc-c++ >= 7, since that is the
  first version that supports C++17
- Run tests on all distributions and architectures
  * Allow disabling them on command line by specifying
    "--without tests"
- Changed patch:
  * no-std-filesystem.patch -> liborcus-filesystem.patch
    + rework the patch to detect std::filesystem,
    std::experimental::filesystem and boost::filesystem (in that
    order, and use them if found)
- Added patch:
  * liborcus-tests.patch
    + fix tests on all platforms
    + do not use C++20 features with the
    boost::filesystem::directory_iterator
    + do not assume that pathlib integrates seamlessly with open
    and do not use f-string formating, both being python 3.6+
    features
* Thu Jun 29 2023 Danilo Spinella <danilo.spinella@suse.com>
- Update to 0.18.1:
  * sax parser:
  * added support for optionally skipping multiple BOM's in the beginning of
    XML stream.  This affects all XML-based file format filters such as
    xls-xml (aka Excel 2003 XML).
  * xml-map:
  * fixed a bug where an XML document consisting of simple single-column
    records were not properly converted to sheet data.
  * xls-xml:
  * fixed a bug where the filter would always pass border color even when it
    was not set.
  * buildsystem:
  * added new configure switches --without-benchmark and --without-doc-example
    to optinally skip building of these two directories.
- Remove patch gcc13-fix.patch
* Fri Mar 10 2023 Martin Liška <mliska@suse.cz>
- Use -fexcess-precision=fast in order to support GCC compiler:
  https://gcc.gnu.org/gcc-13/porting_to.html#excess-precision.
  Fixes: https://gitlab.com/orcus/orcus/-/issues/175
* Mon Mar  6 2023 Martin Liška <mliska@suse.cz>
- Add include fix gcc13-fix.patch for GCC 13 compiler.
* Thu Jan 27 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * no-std-filesystem.patch
    + use boost::filesystem instead of std::filesystem, in order to
    allow building with older compilers
* Wed Jan 26 2022 Danilo Spinella <danilo.spinella@suse.com>
- Update to 0.17.2:
  * fixed a bug where the state of style:cell-protect="none" was not
    explicitly pushed, thereby having had the same effect as not having this
    attribute.  After the fix, style:cell-protect="none" will explicitly push
    the hidden state to false, locked state to false, and the formula-hidden
    state to false.
- Update to 0.17.1:
  * addressed a number of coverity issues.
  * removed a variety of compiler warnings.
  * re-generated sax parser tokens from ODF v1.3.
  * revised the style import code to only push style attributes that are
    actually specified in the XML.
  * revised the XML structure validation strategy to ignore any mis-placed
    elements and their sub structures rather than aborting the import.
* Fri Nov 19 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 0.17.0:
  * set the baseline C++ version to 17.
  * cleaned up the public API to replace pstring with std::string_view, union
    with std::variant, and boost::optional with std::optional.  With this
    change, the public API no longer has dependency on boost.
  * switched to using ixion::model_iterator for horizontal iteration of cells
    instead of using mdds::mtv::collection.
  * fixed a bug where exporting a spreadsheet document containing adjacent
    merged cells regions to html incorrectly exported the merged cell areas.
  * cached cell values are now correctly loaded from the xlsx file.
  * utf-8 names are now allowed as element and attribute names in the sax parser.
  * unquoted utf-8 property values are now allowed in the css parser.
  * added yaml output option in orcus-json.
  * fixed a bug where mapping of an XML document with namespace aliases
    sometimes corrupts the alias values.
  * added orcus.FormulaTokenOp enum type in python which describes type formula token
    operator types in a more finer grained manner.
  * added notes to how to use orcus-xml and orcus-json to map XML and JSON
    documents to spreadsheet documents.
- Drop GCC11_build_fixes.patch
* Wed May 19 2021 Fridrich Strba <fstrba@suse.com>
- Define conditionally make_build to fix build on systems that do
  not have that macro
* Tue Feb  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream changes to fix build with GCC 11 (boo#1181872):
  * GCC11_build_fixes.patch
* Wed Oct 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.16.1:
  * match up with ixion 0.16 release
* Mon Mar 30 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.15.4:
  * Bugfixes release
* Fri Oct 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.15.3:
  * Minor fixes around fixing various xml related bugs
* Fri Aug 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.15.1:
  * minor bugfixes after the 0.15.0 was released
- Remove merged patches
  * fix-linking.patch
  * 32bit.patch
* Fri Aug 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix building on SLE12
- Add patches to fix 32bit build:
  * fix-linking.patch
  * 32bit.patch
* Thu Aug 15 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 0.15.0:
  * Various performance improvements
  * Multiple parser issues fixed
  * Map and structure mode added to orcus-json
  * Other improvements and fixes
- bump required versions of mdds and libixion
* Thu Mar  7 2019 Adam Majer <adam.majer@suse.de>
- Add missing dependency on libboost_system-devel
* Thu Nov 15 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 0.14.1:
  * addressed a number of coverity issues.
  * Boost 1.67 support
    + Drop patch boost_1_67.patch
  * Various cell handling issues fixed
* Wed May 23 2018 adam.majer@suse.de
- boost_1_67.patch: fix building with Boost 1.67 (bsc#1089811)
* Tue Feb 27 2018 tchvatal@suse.com
- Version updat eto 0.13.4:
  * Various false positive fixes in detection of xml files
* Thu Feb 15 2018 tchvatal@suse.com
- Version update to 0.13.3:
  * Various improvements in 2003 XML imports
- Rename name-python3 to python3-name to match other python modules
* Tue Jan 30 2018 tchvatal@suse.com
- Version update to 0.13.2:
  * Various small fixes
  * Improvements in Excel 2003 XML import iflter
* Fri Jan  5 2018 tchvatal@suse.com
- Fix python-xml dep to properly state python3-xml
* Thu Dec 14 2017 tchvatal@suse.com
- Switch license to MPL-2.0
* Wed Nov 29 2017 tchvatal@suse.com
- Update to 0.13.1:
  * Required by libreoffice 6.0
  * Fixes many crashers
  * Speedup improvements
  * More features for xslx importer
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Dec  3 2016 tchvatal@suse.com
- Version update to 0.12.1 as required by lo 5.3
* Wed May 25 2016 tchvatal@suse.com
- Version update to 0.11.2:
  * Fix build with mdds 1.2
  * few small fixes
* Wed May 25 2016 dimstar@opensuse.org
- Changes from version 0.11.1:
  + Fix for OSX build inside LibreOffice.
  + Boost.Filesystem is needed uncoditionally.
* Thu May 12 2016 tchvatal@suse.com
- Fix libixion -> liborcus typo
* Thu May  5 2016 tchvatal@suse.com
- Coflict with liborcus-0_10-0
* Tue Mar  8 2016 fstrba@suse.com
- Change package name to correspond to the soname  of the
  libraries provided.
* Mon Mar  7 2016 tchvatal@suse.com
- Version update to 0.11.0:
  * Use mdds 1.0
  * Use ixion 0.11
  * Use python3 instead of python2
* Mon Dec 21 2015 tchvatal@suse.com
- Version update to 0.9.2:
  * Various bugfixes and update for libreoffice 5.1
* Tue Mar 24 2015 tchvatal@suse.com
- Version bump to 0.7.1:
  * Various boost bugfixes and update for new ixion
- Obsoleted patch:
  * liborcus-boost-1.56.patch
* Mon Oct 27 2014 dmitry_r@opensuse.org
- Fix build with boost-1.56
  * liborcus-boost-1.56.patch
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.7.0
- Remove unneeded upstreamed patches:
  * liborcus-more-lib64.patch
  * liborcus-0.5.1-linking.patch
  * liborcus-0.5.1-mdds.patch
  * liborcus-0.5.1-oldnamespace.patch
- Use pkgconfig BuildRequires wherever it is possible
* Sat Jan 25 2014 tchvatal@suse.com
- Clean with spec-cleaner and Verbosify the output.
* Mon Jan  6 2014 matz@suse.com
- Add aarch64 and ppc64le to list of 64bit archs for boost_system
  detection.
  Added patches:
  * liborcus-more-lib64.patch
* Tue Nov 12 2013 jengelh@inai.de
- Correct description not to mention an N-gram text categorizer
* Thu Aug  1 2013 tchvatal@suse.com
- Version bump to 0.5.1:
  * More fixes around streaming
  * Various boost fixes
  * Improvements required for libreoffice-4.1.
- Use full download url for tarball
- Drop libzip-devel requirement
- Add patch for new mdds liborcus-0.5.1-mdds.patch
- Add patch for SLE11 gcc liborcus-0.5.1-oldnamespace.patch
- Add patch for newest boost liborcus-0.5.1-linking.patch
- Drop deprecated patch boost-configure.patch
* Sun Jun 16 2013 schwab@suse.de
- boost-configure.patch: fix boost configure check
* Fri May 31 2013 tchvatal@suse.com
- Fix building with boost-1.52 and newer.
* Wed Feb  6 2013 pmladek@suse.com
- Add libzip-devel and zlib-devel into Requires of the devel package;
  they are needed for linking against liborcus
* Tue Jan  8 2013 tchvatal@suse.com
- Rename package and sort it out for acceptance to factory.
* Tue Dec 18 2012 tchvatal@suse.com
- Build gnumeric filters as libreoffice check for them.
  * cleanup the spec a bit.
* Wed Nov 28 2012 kyoshida@suse.com
- Official 0.3.0 package.
* Sat Nov 10 2012 kyoshida@suse.com
- Updated snapshot from the latest master branch.
* Fri Oct  5 2012 kyoshida@suse.com
- Latest development snapshot from the master branch.
* Tue Oct  2 2012 kyoshida@suse.com
- Latest development snapshot from the master branch.
* Wed Sep 26 2012 kyoshida@suse.com
- Remove the obsolete package and spec.
* Wed Sep 26 2012 kyoshida@suse.com
- Add new package and spec from the latest master branch.
* Thu Sep  6 2012 kyoshida@suse.com
- Updated the package with all sorts of fixes.
* Thu Aug 30 2012 kyoshida@suse.com
- Updated the package.  It now supports --disable-libzip.
* Tue Jul 31 2012 kyoshida@suse.com
- Modified spec file to keep rpmlint happy.
* Tue Jul 31 2012 kyoshida@suse.com
- Added initial spec file.
